Crate kcr_acid_zalan_do

Crate kcr_acid_zalan_do 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the acid.zalan.do group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

acid.zalan.do/v1

  • OperatorConfiguration
  • postgresql
  • PostgresTeam

Modules

v1